@@ -1,6 +1,6 @@
 let () =
   let version =
-    Scanf.sscanf Sys.ocaml_version "%d.%d" (fun major minor -> (major, minor))
+    Scanf.sscanf Sys.argv.(1) "%d.%d" (fun major minor -> (major, minor))
   in
   let file =
     if version < (4, 03) then
